/*  Sony RM-X2S plugin for xmms by Dirk Jagdmann <doj@cubic.org>
 *                                 http://llg.cubic.org
 *
 *  XMMS is Copyright (C) 1998-2000 Peter Alm, Mikael Alm, Olle
 *  Hallnas, Thomas Nilsson and 4Front Technologies
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.  */

/* $Header: /home/cvs/sonyjoy/sony.h,v 1.10 2006/05/05 20:10:33 doj Exp $ */

#ifndef _SONY_H_
#define _SONY_H_

/* System general includes */
#include <linux/joystick.h>

#define JOYSTICK_MAX_AXIS 8
#define AXIS_NUMBER 0

/* XMMS-required includes (glib, threads) */
#include <glib.h>
#include <gtk/gtk.h>
#include <pthread.h>
#include <xmms/plugin.h>
#include <xmms/xmmsctrl.h>
#include <xmms/configfile.h>

/** enums to identify joystick event */
typedef enum sonyrm_cmd_en
{
  SONY_EJECT = 0,
  SONY_PLAY,
  SONY_STOP,
  SONY_NEXT,
  SONY_PREV,
  SONY_VOLUP,
  SONY_VOLDOWN,
  SONY_REPEAT,
  SONY_SHUFFLE,
  SONY_AOT,
  SONY_EQWIN,
  SONY_MAINWIN,
  SONY_PLWIN,
  SONY_PREFWIN,
  SONY_NUM /* this is no event, but a c-trick to calculate the number of events */
} sonyrm_cmd;

/** various defines needed for the plugin */
typedef enum sonyrm_id_en
{
  SONY_IGNORE_CALIBRATION=0x80,
  SONY_INITIAL_BITMASK=0xFFF0,
  SONY_BUTTON = 70000,
  SONY_NIL
} sonyrm_id;

extern char *sonyrm_configstr[];

/** configuration structure for sonyrm plugin */
typedef struct sonyrm_config_st
{
  gchar *device;
  gint command[SONY_NUM];
  guint16 bitmask;
  struct js_corr correction;
}
sonyrm_config;

extern sonyrm_config sonyrm_cfg;

void sonyrm_about();
void sonyrm_configure();
void sonyrm_read_config();
void sonyrm_save_config();
void sonyrm_copy(sonyrm_config *dest, sonyrm_config *src);
const gboolean sonyrm_active();
void sonyrm_init();
void sonyrm_cleanup();
int sonyrm_open(sonyrm_config *cfg);
void sonyrm_calibrate_init(GtkWidget * w, gpointer data);
void sonyrm_dumpconfig(sonyrm_config *cfg);
void sonyrm_addstatus(const gchar *text);

#ifdef ENABLE_NLS
#include <libintl.h>
#define _(String) gettext (String)
#else
#define _(String) (String)
#endif

#endif
